Module ir

Module ir 

Intermediate representation (IR) for ISO 20022 schema types.

The IR is the bridge between the raw XSD AST produced by crate::xsd and the Rust token stream emitted by crate::emit. It is deliberately closer to Rust than to XSD, making the emitter simple.

Entry points

Re-exports

pub use lower::lower;
pub use lower::LowerError;
pub use types::AttrDef;
pub use types::Cardinality;
pub use types::CodeEnumDef;
pub use types::CodeValue;
pub use types::Constraint;
pub use types::EnumDef;
pub use types::FieldDef;
pub use types::NewtypeDef;
pub use types::OpaqueDef;
pub use types::RootElement;
pub use types::RustType;
pub use types::StructDef;
pub use types::TypeDef;
pub use types::TypeGraph;
pub use types::TypeRef;
pub use types::ValueWithAttrDef;
pub use types::VariantDef;

Modules

lower
XSD AST → IR lowering pass.
types
Intermediate representation types.